@@ -12,7 +12,7 @@ use Padre::Wx       ();
 use Padre::Action   ();
 use Padre::Current qw{_CURRENT};
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 
 
@@ -170,6 +170,120 @@ sub new {
 	return $self;
 }
 
+#####################################################################
+# Module Tools
+
+sub install_file {
+	my $self = shift;
+	my $main = shift;
+
+	# Ask what we should install
+	my $dialog = Wx::FileDialog->new(
+		$main,
+		Wx::gettext("Select distribution to install"),
+		'',                                  # Default directory
+		'',                                  # Default file
+		'CPAN Packages (*.tar.gz)|*.tar.gz', # wildcard
+		Wx::wxFD_OPEN | Wx::wxFD_FILE_MUST_EXIST
+	);
+	$dialog->CentreOnParent;
+	if ( $dialog->ShowModal == Wx::wxID_CANCEL ) {
+		return;
+	}
+	my $string = $dialog->GetPath;
+	$dialog->Destroy;
+	unless ( defined $string and $string =~ /\S/ ) {
+		$main->error( Wx::gettext("Did not provide a distribution") );
+		return;
+	}
+
+	$self->install_pip( $main, $string );
+	return;
+}
+
+sub install_url {
+	my $self = shift;
+	my $main = shift;
+
+	# Ask what we should install
+	my $dialog = Wx::TextEntryDialog->new(
+		$main,
+		Wx::gettext("Enter URL to install\ne.g. http://svn.ali.as/cpan/releases/Config-Tiny-2.00.tar.gz"),
+		"pip",
+		'',
+	);
+	if ( $dialog->ShowModal == Wx::wxID_CANCEL ) {
+		return;
+	}
+	my $string = $dialog->GetValue;
+	$dialog->Destroy;
+	unless ( defined $string and $string =~ /\S/ ) {
+		$main->error( Wx::gettext("Did not provide a distribution") );
+		return;
+	}
+
+	$self->install_pip( $main, $string );
+	return;
+}
+
+sub install_pip {
+	my $self   = shift;
+	my $main   = shift;
+	my $module = shift;
+
+	# Find 'pip', used to install modules
+	require File::Which;
+	my $pip = scalar File::Which::which('pip');
+	unless ( -f $pip ) {
+		$main->error( Wx::gettext("pip is unexpectedly not installed") );
+		return;
+	}
+
+	$main->setup_bindings;
+
+	# Run with console Perl to prevent unexpected results under wperl
+	my $perl = Padre::Perl::cperl();
+	my $cmd  = qq{"$perl" "$pip" "$module"};
+	local $ENV{AUTOMATED_TESTING} = 1;
+	Wx::Perl::ProcessStream::Process->new->Run( $cmd, 'CPAN_mod', $main );
+
+	return;
+}
+
+sub cpan_config {
+	my $self = shift;
+	my $main = shift;
+
+	# Locate the CPAN config file(s)
+	my $default_dir = '';
+	eval {
+		require CPAN;
+		$default_dir = $INC{'CPAN.pm'};
+		$default_dir =~ s/\.pm$//is; # remove .pm
+	};
+
+	# Load the main config first
+	if ( $default_dir ne '' ) {
+		my $core = File::Spec->catfile( $default_dir, 'Config.pm' );
+		if ( -e $core ) {
+			$main->setup_editors($core);
+			return;
+		}
+	}
+
+	# Fallback to a personal config
+	my $user = File::Spec->catfile(
+		File::HomeDir->my_home,
+		'.cpan', 'CPAN', 'MyConfig.pm'
+	);
+	if ( -e $user ) {
+		$main->setup_editors($user);
+		return;
+	}
+
+	$main->error( Wx::gettext("Failed to find your CPAN configuration") );
+}
+
 1;
 
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
